McCabe complexity checker
=========================

This module provides a plugin for ``flint``, the Python code checker.

.. note::
   ``flint`` is now merged into `Flake8 2.0
   <https://pypi.python.org/pypi/flake8>`_.
   Please consider https://pypi.python.org/pypi/mccabe instead.


Plugin for Flint
----------------

When both ``flint`` and ``flint-mccabe`` are installed, the plugin is
available in ``flint``::

  $ flint --version
  0.1 (pep8: 1.4.2, pyflakes: 0.6.1, mccabe: 0.2)

By default the plugin is disabled.  Use the ``--max-complexity`` switch to
enable it.  It will emit a warning if the McCabe complexity of a function is
higher that the value::

    $ flint --max-complexity 10 coolproject
    ...
    coolproject/mod.py:1204:1: C901 'CoolFactory.prepare' is too complex (14)

This feature is quite useful to detect over-complex code. According to McCabe,
anything that goes beyond 10 is too complex.


Changes
-------

0.2 - 2013-02-23
````````````````

* Release the package ``mccabe`` and depend on it.


0.1 - 2013-02-11
````````````````
* First release
